@@ -262,6 +262,7 @@ class MarketAnalyzer:
 
         if only_one_per_type :
             print('keeping only the best per filter type')
+            kpis_df = kpis_df.T
             kpis_df['label'] = kpis_df.index
 
             def get_algo_type(row):
@@ -281,10 +282,13 @@ class MarketAnalyzer:
             signal_grouped_kpis.index = signal_grouped_kpis.label
 
             kpis_df = signal_grouped_kpis.copy()
+            kpis_df =  kpis_df[~kpis_df.index.isin(['label','labeltype'])]
+            kpis_df = kpis_df.T
 
 
 
-        # return set_table(results, self.assets, self.metrics)
+
+            # return set_table(results, self.assets, self.metrics)
         return kpis_df
 
     def display_kpi(self, title='KPI table'):
