@@ -37,5 +37,4 @@ class NapoleonQuoteServiceConnector(TemplateConnector):
 
 
 if __name__ == '__main__':
-    test = NapoleonQuoteServiceConnector().filter(data=EodQuoteFilter(["STRAT_BTC_USD_D_3"],lastOnly=True))
-    pass
\ No newline at end of file
+    test = NapoleonQuoteServiceConnector()
\ No newline at end of file
